@@ -74,7 +74,7 @@
 /*	The message is in the \fBhold\fR queue, i.e. no further delivery
 /*	attempt will be made until the mail is taken off hold.
 /* .IP \fB#\fR
-/*	The message is force-expired. See the \fBpostsuper\fR(1)
+/*	The message is forced to expire. See the \fBpostsuper\fR(1)
 /*	options \fB-e\fR or \fB-f\fR.
 /* .sp
 /*	This feature is available in Postfix 3.5 and later.
@@ -121,8 +121,8 @@
 /*	number does not include message envelope information. It
 /*	is approximately equal to the number of bytes that would
 /*	be transmitted via SMTP including the <CR><LF> line endings.
-/* .IP \fBforce_expired\fR
-/*	The message is force-expired (\fBtrue\fR or \fBfalse\fR).
+/* .IP \fBforced_expire\fR
+/*	The message is forced to expire (\fBtrue\fR or \fBfalse\fR).
 /*	See the \fBpostsuper\fR(1) options \fB-e\fR or \fB-f\fR.
 /* .sp
 /*	This feature is available in Postfix 3.5 and later.
@@ -361,6 +361,11 @@ static void show_queue(int mode)
      * Connect to the show queue service.
      */
     if ((showq = mail_connect(MAIL_CLASS_PUBLIC, var_showq_service, BLOCKING)) != 0) {
+	if (attr_scan(showq, ATTR_FLAG_STRICT | ATTR_FLAG_MORE,
+		    RECV_ATTR_STREQ(MAIL_ATTR_PROTO, MAIL_ATTR_PROTO_SHOWQ),
+		      ATTR_TYPE_END) != 0)
+	    msg_fatal_status(EX_SOFTWARE, "malformed showq server response");
+
 	switch (mode) {
 	case PQ_MODE_MAILQ_LIST:
 	    showq_compat(showq);
@@ -407,6 +412,11 @@ static void show_queue(int mode)
 				   CA_VSTREAM_POPEN_END)) == 0) {
 	    stat = -1;
 	} else {
+	    if (attr_scan(showq, ATTR_FLAG_STRICT | ATTR_FLAG_MORE,
+		    RECV_ATTR_STREQ(MAIL_ATTR_PROTO, MAIL_ATTR_PROTO_SHOWQ),
+			  ATTR_TYPE_END) != 0)
+		msg_fatal_status(EX_SOFTWARE, "malformed showq server response");
+
 	    switch (mode) {
 	    case PQ_MODE_MAILQ_LIST:
 		showq_compat(showq);
